@@ -241,6 +241,15 @@ class SliceAgain(LazyEvaluation):
         return sliceobj(expression, data)
 
 
+def percent(expression: str):
+    """
+    Allows specification of percentages.
+    """
+    if expression.endswith('%'):
+        return float(expression[:-1].strip()) / 100
+    return float(expression)
+
+
 def sliceobj(expression: Union[int, str, slice], data: Optional[Chunk] = None, range=False, final=False) -> Union[slice, SliceAgain]:
     """
     Uses `refinery.lib.argformats.PythonExpression` to parse slice expressions
@@ -1087,7 +1096,8 @@ class DelayedArgument(LazyEvaluation):
             size, remainder = divmod(arg.bit_length(), 8)
             if remainder: size += 1
             return arg.to_bytes(size, 'big')
-        return int.from_bytes(arg, 'big')
+        else:
+            return int.from_bytes(arg, 'big')
 
     @handler.register('le')
     def le(self, arg: Union[int, ByteString]) -> int:
@@ -1098,7 +1108,8 @@ class DelayedArgument(LazyEvaluation):
             size, remainder = divmod(arg.bit_length(), 8)
             if remainder: size += 1
             return arg.to_bytes(size, 'little')
-        return int.from_bytes(arg, 'little')
+        else:
+            return int.from_bytes(arg, 'little')
 
     @handler.register('reduce')
     def reduce(self, it: Iterable[int], reduction: str, seed: Optional[str] = None) -> int:
