@@ -117,6 +117,7 @@ import contextlib
 import string
 import codecs
 import itertools
+import os
 
 from io import StringIO
 from urllib.parse import quote_from_bytes, unquote_to_bytes
@@ -124,6 +125,7 @@ from typing import Callable, Dict, Iterable, Optional, ByteString, Union, TYPE_C
 
 from refinery.lib.structures import MemoryFile
 from refinery.lib.tools import isbuffer, entropy, index_of_coincidence
+from refinery.lib.environment import environment
 
 
 if TYPE_CHECKING:
@@ -153,16 +155,25 @@ class CustomStringRepresentation(abc.ABC):
     def __repr__(self): ...
 
 
-_PRINTABLE = (
-    B'0123456789'
-    B'!#$%&()*,-./:;=?@[\\]{}~'
-    B'abcdefghijklmnopqrstuvwxyz'
-    B'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
-)
+_PRINT_SAFE = set(string.printable.encode('latin1')) - set(b'|<>&\t\n\r\x0B\x0B')
+if os.name == 'nt':
+    _PRINT_SAFE -= set(b'^"')
+else:
+    _PRINT_SAFE -= set(b'*?\'"')
+_PRINT_SAFE = bytes(_PRINT_SAFE)
+_IS_PRINT_SAFE = bytearray(256)
+for p in _PRINT_SAFE:
+    _IS_PRINT_SAFE[p] = 1
 
-_IS_PRINTABLE = bytearray(256)
-for p in _PRINTABLE:
-    _IS_PRINTABLE[p] = 1
+
+def is_print_safe(string: str):
+    if not string.isprintable():
+        return False
+    for letter in string:
+        code = ord(letter)
+        if code < len(_IS_PRINT_SAFE) and not _IS_PRINT_SAFE[code]:
+            return False
+    return True
 
 
 class ByteStringWrapper(bytearray, CustomStringRepresentation):
@@ -256,14 +267,14 @@ class ByteStringWrapper(bytearray, CustomStringRepresentation):
         except AttributeError:
             representation = None
         else:
-            if not representation.isprintable() or any(c in representation for c in '&<|>'):
+            if not is_print_safe(representation):
                 representation = None
             elif prefix != 's' or self.requires_prefix(representation):
                 representation = F'{prefix}:{representation}'
         if representation is None:
-            if sum(_IS_PRINTABLE[c] for c in self) >= len(self) * 0.8:
+            if sum(_IS_PRINT_SAFE[c] for c in self) > len(self) * 0.6:
                 from urllib.parse import quote_from_bytes
-                quoted = quote_from_bytes(self, _PRINTABLE)
+                quoted = quote_from_bytes(self, _PRINT_SAFE)
                 representation = F'q:{quoted}'
             else:
                 representation = F'h:{self.hex()}'
@@ -312,25 +323,28 @@ class SizeInt(int, CustomStringRepresentation):
     width = 9
     align = True
 
-    def __repr__(self):
-        step = 1000.0
-        unit = None
-        result = self
-        for unit in [None, 'kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB']:
-            if unit and result / step <= 0.1:
-                break
-            result /= step
-        if unit is None:
-            width = 3 if self.align else 1
-            return F'{result:{width}} BYTES'
-        else:
-            width = 6 if self.align else 1
-            comma = 3 if self.align else 1
-            return F'{result:0{width}.{comma}f} {unit}'
-
     def __str__(self):
         return str(int(self))
 
+    if environment.disable_size_format.value:
+        __repr__ = __str__
+    else:
+        def __repr__(self):
+            step = 1000.0
+            unit = None
+            result = self
+            for unit in [None, 'kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB']:
+                if unit and result / step <= 0.1:
+                    break
+                result /= step
+            if unit is None:
+                width = 3 if self.align else 1
+                return F'{result:{width}} BYTES'
+            else:
+                width = 6 if self.align else 1
+                comma = 3 if self.align else 1
+                return F'{result:0{width}.{comma}f} {unit}'
+
 
 class TerseSizeInt(SizeInt):
     """
