@@ -187,6 +187,11 @@ _pattern_defanged_hostname = _pattern_defanged_socket + '?'
 
 _pattern_integer = '[-+]?(?:0[bB][01]+|0[xX][0-9a-fA-F]+|0[1-7][0-7]*|[1-9][0-9]*|0)(?=[uU]?[iI]\\d{1,2}|[LlHh]|[^a-zA-Z0-9]|$)'
 _pattern_float = R'[-+]?[0-9]*\.?[0-9]+(?:[eE][-+]?[0-9]+)?'
+_pattern_number = F'(?:(?:{_pattern_integer})|(?:{_pattern_float}))'
+_pattern_number = (
+    '[-+]?(?:0[bB][01]+|0[xX][0-9a-fA-F]+|0[1-7][0-7]*|(?:[1-9][0-9]*|0)(?P<fp1>\\.[0-9]*)?|(?P<fp2>\\.[0-9]+))'
+    '(?(fp1)(?:[eE][-+]?[0-9]+)?|(?(fp2)(?:[eE][-+]?[0-9]+)?|(?=[uU]?[iI]\\d{1,2}|[LlHh]|[^a-zA-Z0-9]|$)))'
+)
 _pattern_cmdstr = R'''(?:"(?:""|[^"])*"|'(?:''|[^'])*')'''
 _pattern_ps1str = R'''(?:@"\s*?[\r\n].*?[\r\n]"@|@'\s*?[\r\n].*?[\r\n]'@|"(?:`.|""|[^"])*"|'(?:''|[^'])*')'''
 _pattern_vbastr = R'''"(?:""|[^"])*"'''
@@ -197,6 +202,9 @@ _pattern_urlenc_coarse = R'''(?:%[0-9a-fA-F]{2}|[0-9a-zA-Z\-\._~\?!$&=:\/#\[\]@'
 _pattern_urlenc = R'''(?:%[0-9a-fA-F]{2}|[0-9a-zA-Z\-\._~\?!$&=])+'''
 _pattern_urlenc_narrow = R'''(?:%[0-9a-fA-F]{2})+'''
 
+_pattern_json = R'''[\[\{](?:"(?:[^"\\\r\n]|\\[^\r\n])*"(?:\s*[:,])?|(?:none|true|false|%s|%s|\]|\})(?:\s*,)?|[,\]\}\[\{\s]+)*[\]\}]''' % (
+    _pattern_integer, _pattern_float)
+
 _pattern_wshenc = R'''#@~\^[ -~]{6}==(?:.*?)[ -~]{6}==\^#~@'''
 
 _part_url_credentials = (
@@ -266,6 +274,11 @@ __all__ = [
 ]
 
 
+class checks(PatternEnum):
+    json = pattern(_pattern_json)
+    "Data that consists of JSON-like tokens; cannot detect actual JSON data."
+
+
 class formats(PatternEnum):
     """
     An enumeration of patterns for certain formats.
@@ -274,6 +287,8 @@ class formats(PatternEnum):
     "Integer expressions"
     float = pattern(_pattern_float)
     "Floating point number expressions"
+    number = pattern(_pattern_number)
+    "Either an integer or a float"
     string = pattern(_pattern_string)
     "C syntax string literal"
     multiline_string = pattern(_pattern_string_multiline)
@@ -296,6 +311,8 @@ class formats(PatternEnum):
     "A hex-encoded buffer using URL escape sequences"
     intarray = tokenize(_pattern_integer, sep=R'\s*[;,]\s*', bound='', unique_sep=True)
     "Sequences of integers, separated by commas or semicolons"
+    numarray = tokenize(_pattern_number, sep=R'\s*[;,]\s*', bound='', unique_sep=True)
+    "Sequences of numbers, separated by commas or semicolons"
     word = alphabet(R'\\w')
     "Sequences of word characters"
     letters = alphabet(R'[a-zA-Z]')
@@ -306,11 +323,13 @@ class formats(PatternEnum):
     "Sequences of alpha-numeric characters"
     b32 = pattern('[A-Z2-7]+|[a-z2-7+]')
     "Base32 encoded strings"
-    b64 = alphabet(R'(?:[-\w\+/]{4})', postfix=R'(?:(?:[-\w\+/]{2,3})={0,3})?')
+    b64 = alphabet(R'(?:[0-9a-zA-Z\+/]{4})', postfix=R'(?:(?:[0-9a-zA-Z\+/]{2,3})={0,3})?')
     "Base64 encoded strings"
+    b64any = alphabet(R'(?:[-\w\+/]{4})', postfix=R'(?:(?:[-\w\+/]{2,3})={0,3})?')
+    "Both URL-safe and normal Base64 alphabets."
     b64space = alphabet(R'[-\s\w\+/]', postfix=R'(?:={0,3})?')
     "Base64 encoded strings, separated by whitespace"
-    b64url = alphabet(R'[0-9a-zA-Z\_\-]{4}', postfix=R'(?:[0-9a-zA-Z\_\-]{2,3}={0,3})?')
+    b64url = alphabet(R'[-\w]{4}', postfix=R'(?:[-\w]{2,3}={0,3})?')
     "Base64 encoded strings using URL-safe alphabet"
     hex = alphabet(R'[0-9a-fA-F]{2}')
     "Hexadecimal strings"
@@ -338,16 +357,28 @@ class formats(PatternEnum):
 
 
 class wallets(PatternEnum):
-    LTC = pattern("[LM3][a-km-zA-HJ-NP-Z1-9]{26,33}")
-    DASH = pattern("X[1-9A-HJ-NP-Za-km-z]{33}")
-    XMR = pattern("4[0-9AB][1-9A-HJ-NP-Za-km-z]{90,120}")
-    BTC = pattern("[13][a-km-zA-HJ-NP-Z1-9]{25,34}")
-    BTCP = pattern("5[HJK][1-9A-Za-z][^OIl]{48}")
-    ETH = pattern("0x[a-fA-F0-9]{40}")
-    XRP = pattern("r[0-9a-zA-Z]{24,34}")
-    NEO = pattern("A[0-9a-zA-Z]{33}")
+    # https://gist.github.com/etherx-dev/76559d9e6d916917a960e33ceea91481
+    ADA = pattern("addr1[a-z0-9]+")
+    ATOM = pattern("cosmos[-\\w\\.]{10,}")
     BCH = pattern("(bitcoincash:)?(q|p)[a-z0-9]{41}|(BITCOINCASH:)?(Q|P)[A-Z0-9]{41}")
+    BTC = pattern("(?:[13][a-km-zA-HJ-NP-Z1-9]{25,34}|bc1[a-z0-9]{25,39})")
+    BTCP = pattern("5[HJK][1-9A-Za-z][^OIl]{48}")
+    DASH = pattern("X[1-9A-HJ-NP-Za-km-z]{33}")
     DOGE = pattern("D{1}[5-9A-HJ-NP-U]{1}[1-9A-HJ-NP-Za-km-z]{32}")
+    DOT = pattern("1[0-9a-zA-Z]{47}")
+    ETH = pattern("0x[a-fA-F0-9]{40}")
+    IOTA = pattern("iota[a-z0-9]{10,}")
+    LSK = pattern("[0-9]{19}L")
+    LTC = pattern("[LM3][a-km-zA-HJ-NP-Z1-9]{26,33}")
+    NEO = pattern("N[0-9a-zA-Z]{33}")
+    ONE = pattern("(?:bnb|one)1[a-z0-9]{38}")
+    ONT = pattern("A[0-9a-zA-Z]{33}")
+    RONIN = pattern("ronin:[a-fA-F0-9]{40}")
+    TERRA = pattern("terra1[a-z0-9]{38}")
+    XEM = pattern("N[A-Za-z0-9]{4,7}-[A-Za-z0-9]{4,7}-[A-Za-z0-9]{4,7}-[A-Za-z0-9]{4,7}-[A-Za-z0-9]{4,7}-[A-Za-z0-9]{4,7}-[A-Za-z0-9]{4,7}")
+    XLM = pattern("G[A-D][A-Z2-7]{54}")
+    XMR = pattern("4[0-9AB][1-9A-HJ-NP-Za-km-z]{90,120}")
+    XRP = pattern("r[0-9a-zA-Z]{24,34}")
 
 
 class indicators(PatternEnum):
