@@ -528,13 +528,13 @@ class StructReader(MemoryFile[T]):
     def i32(self, peek: bool = False) -> int: return signed(self.read_integer(32, peek), 32)
     def i64(self, peek: bool = False) -> int: return signed(self.read_integer(64, peek), 64)
 
-    def f32(self, peek: bool = False) -> float: return self.read_struct('f', peek=peek)
-    def f64(self, peek: bool = False) -> float: return self.read_struct('d', peek=peek)
+    def f32(self, peek: bool = False) -> float: return self.read_struct('f', unwrap=True, peek=peek)
+    def f64(self, peek: bool = False) -> float: return self.read_struct('d', unwrap=True, peek=peek)
 
     def read_byte(self, peek: bool = False) -> int: return self.read_integer(8, peek)
     def read_char(self, peek: bool = False) -> int: return signed(self.read_integer(8, peek), 8)
 
-    def read_terminated_array(self, alignment: int, terminator: bytes) -> bytearray:
+    def read_terminated_array(self, terminator: bytes, alignment: int = 1) -> bytearray:
         pos = self.tell()
         buf = self.getbuffer()
         try:
@@ -557,13 +557,13 @@ class StructReader(MemoryFile[T]):
             return bytearray(data)
 
     def read_c_string(self, encoding=None) -> Union[str, bytearray]:
-        data = self.read_terminated_array(1, B'\0')
+        data = self.read_terminated_array(B'\0')
         if encoding is not None:
             data = data.decode(encoding)
         return data
 
     def read_w_string(self, encoding=None) -> Union[str, bytearray]:
-        data = self.read_terminated_array(2, B'\0\0')
+        data = self.read_terminated_array(B'\0\0', 2)
         if encoding is not None:
             data = data.decode(encoding)
         return data
@@ -600,18 +600,21 @@ class StructMeta(type):
     """
     A metaclass to facilitate the behavior outlined for `refinery.lib.structures.Struct`.
     """
-    def __new__(mcls, name, bases, nmspc, **kwargs):
-        nmspc.update(kwargs)
+    def __new__(mcls, name, bases, nmspc, parser=StructReader):
         return type.__new__(mcls, name, bases, nmspc)
 
-    def __init__(cls, name, bases, nmspc, **kwargs):
+    def __init__(cls, name, bases, nmspc, parser=StructReader):
         super(StructMeta, cls).__init__(name, bases, nmspc)
         original__init__ = cls.__init__
 
         @functools.wraps(original__init__)
         def wrapped__init__(self: Struct, reader, *args, **kwargs):
-            if not isinstance(reader, StructReader):
-                reader = StructReader(reader)
+            if not isinstance(reader, parser):
+                if issubclass(parser, reader.__class__):
+                    raise ValueError(
+                        F'A reader of type {reader.__class__.__name__} was passed to {cls.__name__}, '
+                        F'but a {parser.__name__} is required.')
+                reader = parser(reader)
             start = reader.tell()
             view = memoryview(reader.getbuffer())
             original__init__(self, reader, *args, **kwargs)
