@@ -45,7 +45,7 @@ def lookahead(iterator: Iterable[_T]) -> Generator[Tuple[bool, _T], None, None]:
 def get_terminal_size(default=0):
     """
     Returns the size of the currently attached terminal. If the environment variable
-    `REFINERY_TERMSIZE` is set to an integer value, it takes prescedence. If the width
+    `REFINERY_TERM_SIZE` is set to an integer value, it takes prescedence. If the width
     of the terminal cannot be determined of if the width is less than 8 characters,
     the function returns zero.
     """
@@ -123,6 +123,24 @@ def documentation(unit):
     return docs.replace('`', '')
 
 
+def begin(iterable: Iterable[_T]) -> Optional[Iterable[_T]]:
+    """
+    Iterates the first element of an iterator and returns None of this fails.
+    Otherwise, it returns a new iterable which will return the same elements
+    as the input.
+    """
+    try:
+        body = iter(iterable)
+        head = next(body)
+    except StopIteration:
+        return None
+    else:
+        def _fused():
+            yield head
+            yield from body
+        return _fused()
+
+
 def skipfirst(iterable: Iterable[_T]) -> Generator[_T, None, None]:
     """
     Returns an interable where the first element of the input iterable was
