@@ -221,9 +221,10 @@ class RefineryPartialResult(ValueError):
 
 
 class RefineryImportMissing(ImportError):
-    def __init__(self, *dependencies: str):
+    def __init__(self, missing: str, *dependencies: str):
         super().__init__()
         import shlex
+        self.missing = missing
         self.install = ' '.join(shlex.quote(dist) for dist in dependencies)
         self.dependencies = dependencies
 
@@ -237,6 +238,13 @@ class RefineryCriticalException(RuntimeError):
     pass
 
 
+class RefineryException(RuntimeError):
+    """
+    This is an exception that was not generated by an external library.
+    """
+    pass
+
+
 class Entry:
     """
     An empty class marker. Any entry point unit (i.e. any unit that can be executed
@@ -337,11 +345,14 @@ class Arg(Argument):
                 if key == 'choices':
                     return ', '.join(self.arg.kwargs['choices'])
                 if key == 'default':
-                    default: Union[bytes, int, str] = self.arg.kwargs['default']
+                    default: Union[bytes, int, str, slice] = self.arg.kwargs['default']
+                    if isinstance(default, slice):
+                        parts = [default.start or '', default.stop or '', default.step]
+                        default = ':'.join(str(x) for x in parts if x is not None)
                     if isinstance(default, int):
-                        return repr(default)
+                        return default
                     if not isbuffer(default):
-                        return str(default)
+                        return default
                     if default.isalnum():
                         return default.decode('latin-1')
                     return F'H:{default.hex()}'
@@ -376,6 +387,19 @@ class Arg(Argument):
             choices = ', '.join([option.name for option in cls])
             raise ValueError(F'Could not transform {value} into {cls.__name__}; the choices are: {choices}') from E
 
+    @classmethod
+    def Counts(
+        cls,
+        *args   : str,
+        help    : Union[omit, str] = omit,
+        dest    : Union[omit, str] = omit,
+        group   : Optional[str] = None,
+    ):
+        """
+        A convenience method to add argparse arguments that introduce a counter.
+        """
+        return cls(*args, group=group, help=help, dest=dest, action='count')
+
     @classmethod
     def Switch(
         cls,
@@ -403,7 +427,9 @@ class Arg(Argument):
         """
         Used to add argparse arguments that contain binary data.
         """
-        return cls(*args, group=group, help=help, dest=dest, nargs=nargs, type=multibin, metavar=metavar or 'B')
+        if metavar is None and any('-' in a for a in args):
+            metavar = 'B'
+        return cls(*args, group=group, help=help, dest=dest, nargs=nargs, type=multibin, metavar=metavar)
 
     @classmethod
     def NumSeq(
@@ -420,6 +446,22 @@ class Arg(Argument):
         """
         return cls(*args, group=group, help=help, nargs=nargs, dest=dest, type=numseq, metavar=metavar)
 
+    @classmethod
+    def Bounds(
+        cls,
+        *args   : str,
+        help    : Union[omit, str] = 'Specify start:end:step in Python slice syntax.',
+        dest    : Union[omit, str] = omit,
+        nargs   : Union[omit, int, str] = omit,
+        default : Union[omit, Any] = omit,
+        metavar : Optional[str] = 'start:end:step',
+        group   : Optional[str] = None,
+    ):
+        """
+        Used to add argparse arguments that contain a slice.
+        """
+        return cls(*args, group=group, help=help, default=default, nargs=nargs, dest=dest, type=sliceobj, metavar=metavar)
+
     @classmethod
     def Number(
         cls,
@@ -625,10 +667,12 @@ class Arg(Argument):
                 self.guessed.discard(key)
                 continue
             if key in them.guessed:
-                if key in self.kwargs and key not in self.guessed:
-                    continue
-                else:
-                    self.guessed.add(key)
+                if key not in self.guessed:
+                    if key == 'type' and self.kwargs.get('action', None) != 'store':
+                        continue
+                    if key in self.kwargs:
+                        continue
+                self.guessed.add(key)
             self.kwargs[key] = value
         self.merge_args(them)
         self.group = them.group or self.group
@@ -831,16 +875,19 @@ class Executable(ABCMeta):
         cls._infer_argspec(parameters, args, cls.__module__)
 
         if not abstract and has_keyword:
-            @wraps(cls.__init__)
-            def init(self, *args, **kwargs):
-                super(cls, self).__init__(*args, **kwargs)
+            cls__init__ = cls.__init__
+
+            @wraps(cls__init__)
+            def new__init__(self, *args, **kwargs):
+                cls__init__(self, *args, **kwargs)
+
             params = [p for p in parameters.values() if p.kind != p.VAR_KEYWORD]
             if inherited:
                 pp = inspect.signature(bases[0].__init__).parameters
                 for name in inherited:
                     params.append(pp[name])
-            init.__signature__ = sig_init.replace(parameters=tuple(params))
-            cls.__init__ = init
+            new__init__.__signature__ = sig_init.replace(parameters=tuple(params))
+            cls.__init__ = new__init__
 
         try:
             initcode = cls.__init__.__code__.co_code
@@ -1104,6 +1151,10 @@ class UnitBase(metaclass=Executable, abstract=True):
         """
 
 
+class requirement(property):
+    pass
+
+
 class Unit(UnitBase, abstract=True):
     """
     The base class for all refinery units. It implements a small set of globally
@@ -1118,30 +1169,35 @@ class Unit(UnitBase, abstract=True):
 
     @staticmethod
     def Requires(distribution: str, optional: bool = True):
-        class Requirement(property):
+        class Requirement(requirement):
             dependency = distribution
-            prefix = 'optional' if optional else 'required'
+            required = not optional
 
             def __init__(self, importer: Callable):
                 super().__init__(importer)
                 self.module = None
 
             def __set_name__(self, unit: Type[Unit], name: str):
-                bucket = F'{self.prefix}_dependencies'
-                dep = getattr(unit, bucket)
-                if dep is None:
-                    dep = set()
-                    setattr(unit, bucket, dep)
-                dep.add(self.dependency)
+                if self.required:
+                    bucket = unit.required_dependencies
+                else:
+                    bucket = unit.optional_dependencies
+                if bucket is None:
+                    bucket = set()
+                    if self.required:
+                        unit.required_dependencies = bucket
+                    else:
+                        unit.optional_dependencies = bucket
+                bucket.add(self.dependency)
 
             def __get__(self, unit: Optional[Type[Unit]], tp: Optional[Type[Executable]] = None):
                 if self.module is not None:
                     return self.module
                 try:
-                    self.module = module = super().fget()
+                    self.module = module = self.fget()
                 except ImportError as E:
-                    args = unit.optional_dependencies or (self.dependency,)
-                    raise RefineryImportMissing(*args) from E
+                    args = unit.optional_dependencies or ()
+                    raise RefineryImportMissing(self.dependency, *args) from E
                 except Exception as E:
                     raise AttributeError(F'module import for distribution "{distribution}" failed: {E!s}')
                 else:
@@ -1230,7 +1286,9 @@ class Unit(UnitBase, abstract=True):
         elif isinstance(exception, GeneratorExit):
             raise exception
         elif isinstance(exception, RefineryImportMissing):
-            self.log_fail(F'dependencies missing; install {exception.install}')
+            self.log_fail(F'dependency {exception.missing} is missing; run pip install {exception.install}')
+        elif isinstance(exception, RefineryException):
+            self.log_fail(exception.args[0])
         else:
             try:
                 explanation = exception.args[0]
@@ -1238,7 +1296,10 @@ class Unit(UnitBase, abstract=True):
                 explanation = exception
             if not isinstance(explanation, str):
                 explanation = exception
-            message = F'exception of type {exception.__class__.__name__}; {explanation!s}'
+            explanation = str(explanation).strip()
+            message = F'exception of type {exception.__class__.__name__}'
+            if explanation:
+                message = F'{message}; {explanation!s}'
             if self.log_level <= LogLevel.INFO and data is not None:
                 from refinery.units.sinks.peek import peek
                 peeked = str(data | peek(lines=2, decode=True, stdout=True))
@@ -1474,16 +1535,26 @@ class Unit(UnitBase, abstract=True):
             return {converter(chunk) for chunk in self}
         elif isinstance(stream, dict):
             key, convert = one(stream.items())
-            output: Dict[Any, List[Any]] = {}
+            output: Dict[Any, Union[List[Chunk], Set[Chunk]]] = {}
+            deconflict = None
+            if isinstance(convert, (list, set)):
+                deconflict = type(convert)
+                convert = one(convert)
             for item in self:
                 try:
                     value = item.meta[key]
                 except KeyError:
                     value = None
-                bag = output.setdefault(value, [])
                 if convert is not ...:
                     item = convert(item)
-                bag.append(item)
+                if deconflict:
+                    bag = output.setdefault(value, deconflict())
+                    if isinstance(bag, list):
+                        bag.append(item)
+                    else:
+                        bag.add(item)
+                else:
+                    output[value] = item
             return output
         elif isinstance(stream, (bytearray, memoryview)):
             with MemoryFile(stream) as stdout:
@@ -1494,7 +1565,7 @@ class Unit(UnitBase, abstract=True):
                 out: bytearray = stdout.getbuffer()
                 if isinstance(stream, type) and isinstance(out, stream):
                     return out
-                if stream is str:
+                if isinstance(stream, type) and issubclass(stream, str):
                     out = out.decode(self.codec)
                 return stream(out)
 
@@ -1661,6 +1732,12 @@ class Unit(UnitBase, abstract=True):
         def transform(message):
             if callable(message):
                 message = message()
+            if isinstance(message, Exception):
+                args = [arg for arg in message.args if isinstance(arg, str)]
+                if len(args) == 1:
+                    message = args[0]
+                else:
+                    message = str(message)
             if isinstance(message, str):
                 return message
             if isbuffer(message):
