@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from Crypto.Cipher import ChaCha20
+from Cryptodome.Cipher import ChaCha20
 from typing import List, Iterable
 
 from refinery.units.crypto.cipher.salsa import LatinCipher
