@@ -4,6 +4,7 @@ from __future__ import annotations
 from typing import List, Type
 
 from refinery.units.formats.archive import ArchiveUnit
+from refinery.units import RefineryException
 
 
 class xt(ArchiveUnit):
@@ -14,6 +15,8 @@ class xt(ArchiveUnit):
     def _handlers(self):
         from refinery.units.formats.office.xtone import xtone
         yield xtone
+        from refinery.units.formats.archive.xtgz import xtgz
+        yield xtgz
         from refinery.units.formats.email import xtmail
         yield xtmail
         from refinery.units.formats.pdf import xtpdf
@@ -24,10 +27,8 @@ class xt(ArchiveUnit):
         yield xtrtf
         from refinery.units.formats.archive.xtnsis import xtnsis
         yield xtnsis
-        from refinery.units.formats.archive.xtzip import xtzip
-        yield xtzip
-        from refinery.units.formats.archive.xt7z import xt7z
-        yield xt7z
+        from refinery.units.formats.archive.xtnode import xtnode
+        yield xtnode
         from refinery.units.formats.archive.xtace import xtace
         yield xtace
         from refinery.units.formats.archive.xtcab import xtcab
@@ -40,16 +41,26 @@ class xt(ArchiveUnit):
         yield xtpyi
         from refinery.units.formats.archive.xttar import xttar
         yield xttar
-        from refinery.units.formats.office.xtdoc import xtdoc
-        yield xtdoc
         from refinery.units.formats.archive.xtiss import xtiss
         yield xtiss
+        from refinery.units.formats.archive.xtzip import xtzip
+        yield xtzip
+        from refinery.units.formats.archive.xt7z import xt7z
+        yield xt7z
+        from refinery.units.formats.msi import xtmsi
+        yield xtmsi
+        from refinery.units.formats.archive.xtnuitka import xtnuitka
+        yield xtnuitka
+        from refinery.units.formats.office.xtdoc import xtdoc
+        yield xtdoc
+        from refinery.units.formats.json import xtjson
+        yield xtjson
         from refinery.units.formats.exe.vsect import vsect
         yield vsect
 
     def unpack(self, data):
         fallback: List[Type[ArchiveUnit]] = []
-        errors = []
+        errors = {}
         pos_args = self.args.paths
         key_args = dict(
             list=self.args.list,
@@ -73,26 +84,33 @@ class xt(ArchiveUnit):
 
             def __iter__(self):
                 handler = self.handler
-                verdict = True if self.fallback else handler.handles(data)
-                if verdict is True:
+                if self.fallback:
+                    verdict = True
+                else:
+                    verdict = handler.handles(data)
+                if verdict is False:
+                    self.unit.log_info(F'rejected: {handler.name}')
+                elif verdict is True:
+                    if not self.fallback:
+                        self.unit.log_info(F'accepted: {handler.name}')
                     try:
                         unit = handler(*pos_args, **key_args)
                     except TypeError as error:
-                        self.unit.log_debug(F'handler {handler.name} failed: {error!s}')
+                        self.unit.log_debug('handler construction failed:', error)
                         return
-                    if not self.fallback:
-                        self.unit.log_info(F'handler {handler.name} can handle this input data')
                     try:
-                        yield from unit.unpack(data)
-                    except Exception as E:
+                        for item in unit.unpack(data):
+                            item.get_data()
+                            yield item
+                    except Exception as error:
                         if not self.fallback:
-                            errors.append(E)
-                        self.unit.log_info(F'unpacking with {handler.name} failed: {E!s}')
+                            errors[handler.name] = error
+                        self.unit.log_debug('handler unpacking failed:', error)
                         return
                     else:
                         self.success = True
                         return
-                if verdict is None:
+                elif verdict is None:
                     fallback.append(handler)
 
         for handler in self._handlers():
@@ -102,7 +120,7 @@ class xt(ArchiveUnit):
             if it.success:
                 return
 
-        self.log_debug(F'fallback order: {list(fallback)}')
+        self.log_debug('fallback order:', lambda: ', '.join(h.name for h in fallback))
 
         for handler in fallback:
             it = unpacker(handler, fallback=True)
@@ -110,7 +128,8 @@ class xt(ArchiveUnit):
             if it.success:
                 return
 
-        if len(errors) == 1:
-            raise errors[0]
-
-        raise ValueError(F'Input data did not match any known archive format ({len(errors)} errors occurred).')
+        if not errors:
+            raise ValueError('input data did not match any known archive format')
+        for name, error in errors.items():
+            self.log_info(F'error when trying to unpack with {name}:', error)
+        raise RefineryException('none of the available unpackers could handle this data')
