@@ -929,7 +929,7 @@ class NSHeader(Struct):
             if k > 0:
                 script.write('\n')
             opcode = self.opcode(instruction)
-            script.write(F'0x{k:0{addr_width}X}: {opcode.name:>{name_width}} ')
+            script.write(F'0x{k:0{addr_width}X}: {opcode.name:<{name_width}} ')
             for j, arg in enumerate(instruction.arguments[:_Op_PARAMETER_COUNT.get(opcode, 6)]):
                 if j > 0:
                     script.write(', ')
@@ -1057,6 +1057,9 @@ class NSArchive(Struct):
         else:
             self.entry_offset_delta = len(header_data)
 
+        if not header_data:
+            raise ValueError('header data had length zero')
+
         xtnsis.log_debug(F'read header of length {len(header_data)}')
 
         self.header = NSHeader(header_data, size=self.size_of_header)
@@ -1241,4 +1244,4 @@ class xtnsis(ArchiveUnit):
 
     @classmethod
     def handles(cls, data: bytearray) -> bool:
-        return cls._find_archive_offset(data, flawmax=1) is not None
+        return any(magic in data for magic in NSArchive.MAGICS)
