@@ -40,6 +40,9 @@ class carve(PatternExtractor):
                 return decoder.unesc(chunk[1:-1])
             from ..encoding.esc import esc
             decoder.unesc = esc()
+        elif self.args.format is formats.integer:
+            from ..encoding.base import base
+            decoder = base()
         elif self.args.format in (formats.uppercase_hex, formats.hex):
             from ..encoding.hex import hex
             decoder = hex()
@@ -49,7 +52,7 @@ class carve(PatternExtractor):
         elif self.args.format is formats.intarray:
             from ..blockwise.pack import pack
             decoder = pack()
-        elif self.args.format is formats.b64:
+        elif self.args.format in (formats.b64, formats.b64any, formats.b64space):
             from ..encoding.b64 import b64
             decoder = b64()
         elif self.args.format is formats.b64url:
