@@ -65,10 +65,6 @@ class peek(HexViewer):
 
     def process(self, data):
         colorize = not self.args.gray and not self.args.stdout
-        if os.name == 'nt' and not self.isatty:
-            # coloring stderr does not work properly in Windows when stdout is redirected:
-            # https://github.com/tartley/colorama/issues/200
-            colorize = False
         lines = self._peeklines(data, colorize)
 
         if self.args.stdout:
@@ -103,6 +99,8 @@ class peek(HexViewer):
         width = max((len(name) for name in meta), default=0)
         separators = iter([sep])
         if _x_peek is not None:
+            if len(_x_peek) > linewidth:
+                _x_peek = _x_peek[:linewidth - 3] + '...'
             yield from separators
             yield _x_peek
         for name in sorted(meta):
@@ -114,7 +112,7 @@ class peek(HexViewer):
             elif isbuffer(value):
                 value = repr(ByteStringWrapper(value))
             elif isinstance(value, int):
-                if value in range(-99, 100):
+                if value in range(-999, 1000):
                     value = str(value)
                 elif value > 0:
                     value = F'0x{value:X}'
@@ -272,7 +270,10 @@ class peek(HexViewer):
             yield separator()
 
     def filter(self, chunks):
-        self._colorama.init(wrap=False)
+        try:
+            self._colorama.init(wrap=False)
+        except ImportError:
+            pass
         discarded = 0
         for final, item in lookahead(chunks):
             item.temp = final
